# Matrix-Alt-Objectlocalization

**Matrix-Alt-Objectlocalization** is an extension package to the [Matrix-Alt-Core](https://pypi.org/project/Matrix-Alt-Core/) framework, designed to add localization and inference capabilities to your Alt Agents 